[![DOI](https://zenodo.org/badge/331695371.svg)](https://zenodo.org/doi/10.5281/zenodo.10392182)
# Berkeley Single Cell Computational Microscopy Dataset

See the [project website](https://waller-lab.github.io/BSCCM/) and [paper](https://arxiv.org/abs/2402.06191) for more information.

For using the `bsccm` python package for using the dataset, see the [Getting Started Jupyter notebook](https://github.com/Waller-Lab/BSCCM/blob/main/Getting_started.ipynb).

Raw data is hosted [here](https://doi.org/10.5061/dryad.sxksn038s), but it is easiest to download using the python package as shown in the notebook
